# GitBio CLI

project that shows your bio (or every person) from GitHub in CLI.

## Requirements

- Python 3.9.2 and pip packages described in `requirements.txt`

## Getting Started

### Ready To Use

Just run `pip install gitbio` (Windows) or `pip3 install gitbio` (Linux/MacOS). Then run `gitbio` command.

## Contributing

If You have problem with running this project using `python gitbio.py` or You want to add new features, you can:
- Create Issue On This Repo
- Fix Problem Using Pull Request. please, follow [these instructions](https://github.com/firstcontributions/first-contributions)

Thanks for support. If there will be more contributing people, I will add list of contributors.

## License

This Project is licensed under the MIT License.